"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MarkdownScreenshot = void 0;
const tslib_1 = require("tslib");
const form_data_1 = tslib_1.__importDefault(require("form-data"));
const common_1 = require("../../common");
const screenshot_utils_1 = require("../utils/screenshot.utils");
const screenshot_1 = require("./screenshot");
const main_config_1 = require("../../main.config");
/**
 * Class representing a Markdown screenshot that extends the base Screenshot class.
 * This class is used to screenshots HTML with markdown content using Gotenberg service.
 *
 * @extends Screenshot
 */
class MarkdownScreenshot extends screenshot_1.Screenshot {
    /**
     * Creates an instance of MarkdownScreenshot.
     * Initializes the Screenshot with the Markdown screenshot route.
     */
    constructor() {
        super(main_config_1.ChromiumRoute.MARKDOWN);
    }
    /**
     * Screenshots HTML with markdown.
     *
     * @param {Object} options - Screenshot options.
     * @param {PathLikeOrReadStream} options.html - PathLike or ReadStream of the HTML content to be screenshoted.
     * @param {PathLikeOrReadStream} options.markdown - PathLike or ReadStream of the Markdown content to be screenshoted.
     * @param {PathLikeOrReadStream} [options.header] - PathLike or ReadStream of the header HTML content.
     * @param {PathLikeOrReadStream} [options.footer] - PathLike or ReadStream of the footer HTML content.
     * @param {ImageProperties} [options.properties] - Image properties for the screenshot.
     * @param {EmulatedMediaType} [options.emulatedMediaType] - Emulated media type for the screenshot.
     * @param {string} [options.waitDelay] - Delay before the screenshot process starts.
     * @param {string} [options.waitForExpression] - JavaScript expression to wait for before completing the screenshot.
     * @param {Record<string, string>} [options.extraHttpHeaders] - Additional HTTP headers for the screenshot.
     * @param {number []} [options.failOnHttpStatusCodes] - Whether to fail on HTTP status code.
     * @param {boolean} [options.failOnConsoleExceptions] - Whether to fail on console exceptions during screenshot.
     * @param {boolean} [options.skipNetworkIdleEvent] - Whether to skip network idle event.
     * @param {boolean} [options.optimizeForSpeed] - Whether to optimize for speed.
     * @returns {Promise<Buffer>} A Promise resolving to the image buffer.
     */
    capture(_a) {
        return tslib_1.__awaiter(this, arguments, void 0, function* ({ html, markdown, header, footer, properties, emulatedMediaType, waitDelay, waitForExpression, extraHttpHeaders, failOnHttpStatusCodes, failOnConsoleExceptions, skipNetworkIdleEvent, optimizeForSpeed }) {
            const data = new form_data_1.default();
            yield common_1.GotenbergUtils.addFile(data, html, 'index.html');
            yield common_1.GotenbergUtils.addFile(data, markdown, 'file.md');
            yield screenshot_utils_1.ScreenshotUtils.customize(data, {
                header,
                footer,
                properties,
                emulatedMediaType,
                waitDelay,
                waitForExpression,
                extraHttpHeaders,
                failOnHttpStatusCodes,
                failOnConsoleExceptions,
                skipNetworkIdleEvent,
                optimizeForSpeed
            });
            return common_1.GotenbergUtils.fetch(this.endpoint, data);
        });
    }
}
exports.MarkdownScreenshot = MarkdownScreenshot;
//# sourceMappingURL=markdown.screenshot.js.map