/// <reference types="node" />
import { PathLikeOrReadStream } from '../../common';
import { ImageProperties } from '../interfaces/screenshot.types';
import { Screenshot } from './screenshot';
import { EmulatedMediaType } from '../interfaces/common.types';
/**
 * Class representing a URL screenshot that extends the base screenshot class.
 * This class is used to screenshot a URL using Gotenberg service.
 *
 * @extends Screenshot
 */
export declare class UrlScreenshot extends Screenshot {
    /**
     * Creates an instance of UrlScreenshot.
     * Initializes the screenshot with the URL screenshot route.
     */
    constructor();
    /**
     * Screenshots URL.
     *
     * @param {Object} options - Screenshot options.
     * @param {string} options.url - The URL of the content to be screenshoted
     * @param {PathLikeOrReadStream} [options.header] - PathLike or ReadStream of the header HTML content.
     * @param {PathLikeOrReadStream} [options.footer] - PathLike or ReadStream of the footer HTML content.
     * @param {ImageProperties} [options.properties] - Image properties for the screenshot.
     * @param {EmulatedMediaType} [options.emulatedMediaType] - Emulated media type for the screenshot.
     * @param {string} [options.waitDelay] - Delay before the screenshot process starts.
     * @param {string} [options.waitForExpression] - JavaScript expression to wait for before completing the screenshot.
     * @param {Record<string, string>} [options.extraHttpHeaders] - Additional HTTP headers for the screenshot.
     * @param {number []} [options.failOnHttpStatusCodes] - Whether to fail on HTTP status code.
     * @param {boolean} [options.failOnConsoleExceptions] - Whether to fail on console exceptions during screenshot.
     * @param {boolean} [options.skipNetworkIdleEvent] - Whether to skip network idle event.
     * @param {boolean} [options.optimizeForSpeed] - Whether to optimize for speed.
     * @returns {Promise<Buffer>} A Promise resolving to the image buffer.
     */
    capture({ url, header, footer, properties, emulatedMediaType, waitDelay, waitForExpression, extraHttpHeaders, failOnHttpStatusCodes, failOnConsoleExceptions, skipNetworkIdleEvent, optimizeForSpeed }: {
        url: string;
        header?: PathLikeOrReadStream;
        footer?: PathLikeOrReadStream;
        properties?: ImageProperties;
        emulatedMediaType?: EmulatedMediaType;
        waitDelay?: string;
        waitForExpression?: string;
        extraHttpHeaders?: Record<string, string>;
        failOnHttpStatusCodes?: number[];
        failOnConsoleExceptions?: boolean;
        skipNetworkIdleEvent?: boolean;
        optimizeForSpeed?: boolean;
    }): Promise<Buffer>;
}
