"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.UrlScreenshot = void 0;
const tslib_1 = require("tslib");
const url_1 = require("url");
const form_data_1 = tslib_1.__importDefault(require("form-data"));
const common_1 = require("../../common");
const screenshot_utils_1 = require("../utils/screenshot.utils");
const screenshot_1 = require("./screenshot");
const main_config_1 = require("../../main.config");
/**
 * Class representing a URL screenshot that extends the base screenshot class.
 * This class is used to screenshot a URL using Gotenberg service.
 *
 * @extends Screenshot
 */
class UrlScreenshot extends screenshot_1.Screenshot {
    /**
     * Creates an instance of UrlScreenshot.
     * Initializes the screenshot with the URL screenshot route.
     */
    constructor() {
        super(main_config_1.ChromiumRoute.URL);
    }
    /**
     * Screenshots URL.
     *
     * @param {Object} options - Screenshot options.
     * @param {string} options.url - The URL of the content to be screenshoted
     * @param {PathLikeOrReadStream} [options.header] - PathLike or ReadStream of the header HTML content.
     * @param {PathLikeOrReadStream} [options.footer] - PathLike or ReadStream of the footer HTML content.
     * @param {ImageProperties} [options.properties] - Image properties for the screenshot.
     * @param {EmulatedMediaType} [options.emulatedMediaType] - Emulated media type for the screenshot.
     * @param {string} [options.waitDelay] - Delay before the screenshot process starts.
     * @param {string} [options.waitForExpression] - JavaScript expression to wait for before completing the screenshot.
     * @param {Record<string, string>} [options.extraHttpHeaders] - Additional HTTP headers for the screenshot.
     * @param {number []} [options.failOnHttpStatusCodes] - Whether to fail on HTTP status code.
     * @param {boolean} [options.failOnConsoleExceptions] - Whether to fail on console exceptions during screenshot.
     * @param {boolean} [options.skipNetworkIdleEvent] - Whether to skip network idle event.
     * @param {boolean} [options.optimizeForSpeed] - Whether to optimize for speed.
     * @returns {Promise<Buffer>} A Promise resolving to the image buffer.
     */
    capture(_a) {
        return tslib_1.__awaiter(this, arguments, void 0, function* ({ url, header, footer, properties, emulatedMediaType, waitDelay, waitForExpression, extraHttpHeaders, failOnHttpStatusCodes, failOnConsoleExceptions, skipNetworkIdleEvent, optimizeForSpeed }) {
            const _url = new url_1.URL(url);
            const data = new form_data_1.default();
            data.append('url', _url.href);
            yield screenshot_utils_1.ScreenshotUtils.customize(data, {
                header,
                footer,
                properties,
                emulatedMediaType,
                waitDelay,
                waitForExpression,
                extraHttpHeaders,
                failOnHttpStatusCodes,
                failOnConsoleExceptions,
                skipNetworkIdleEvent,
                optimizeForSpeed
            });
            return common_1.GotenbergUtils.fetch(this.endpoint, data);
        });
    }
}
exports.UrlScreenshot = UrlScreenshot;
//# sourceMappingURL=url.screenshot.js.map