import FormData from 'form-data';
import { ConversionOptions, PageProperties } from '../interfaces/converter.types';
/**
 * Utility class for handling common tasks related to conversion.
 */
export declare class ConverterUtils {
    /**
     * Adds page properties to the FormData object based on the provided PageProperties.
     *
     * @param {FormData} data - The FormData object to which page properties will be added.
     * @param {PageProperties} pageProperties - The page properties to be added to the FormData.
     */
    static addPageProperties(data: FormData, pageProperties: PageProperties): void;
    /**
     * Customizes the FormData object based on the provided conversion options.
     *
     * @param {FormData} data - The FormData object to be customized.
     * @param {ConversionOptions} options - The conversion options to apply to the FormData.
     * @returns {Promise<void>} A Promise that resolves once the customization is complete.
     */
    static customize(data: FormData, options: ConversionOptions): Promise<void>;
}
