import { ImageProperties, ScreenshotOptions } from './../interfaces/screenshot.types';
import FormData from 'form-data';
/**
 * Utility class for handling common tasks related to screenshot.
 */
export declare class ScreenshotUtils {
    /**
     * Adds page properties to the FormData object based on the provided imageProperties.
     *
     * @param {FormData} data - The FormData object to which page properties will be added.
     * @param {ImageProperties} imageProperties - The page properties to be added to the FormData.
     */
    static addImageProperties(data: FormData, imageProperties: ImageProperties): void;
    /**
     * Customizes the FormData object based on the provided screenshot options.
     *
     * @param {FormData} data - The FormData object to be customized.
     * @param {ScreenshotOptions} options - The screenshot options to apply to the FormData.
     * @returns {Promise<void>} A Promise that resolves once the customization is complete.
     */
    static customize(data: FormData, options: ScreenshotOptions): Promise<void>;
}
