/**
 * Enum representing the available Chromium routes for conversion.
 * @enum {string}
 */
export declare enum ChromiumRoute {
    URL = "url",
    HTML = "html",
    MARKDOWN = "markdown"
}
/**
 * Enum representing the available routes for the PDF engine.
 * @enum {string}
 */
declare enum PdfEngineRoute {
    MERGE = "merge",
    READ_METADATA = "metadata/read",
    WRITE_METADATA = "metadata/write"
}
/**
 * Enum representing the available routes for LibreOffice.
 * @enum {string}
 */
declare enum LibreOfficeRoute {
    CONVERT = "convert"
}
/**
 * Class providing constants and routes for interacting with the Gotenberg service and related engines.
 */
export declare class Chromiumly {
    /**
     * The Gotenberg service endpoint.
     * @type {string}
     */
    static readonly GOTENBERG_ENDPOINT: string;
    /**
     * The path for Chromium-related conversions.
     * @type {string}
     */
    static readonly CHROMIUM_CONVERT_PATH = "forms/chromium/convert";
    /**
     * The path for Chromium-related screenshots.
     * @type {string}
     */
    static readonly CHROMIUM_SCREENSHOT_PATH = "forms/chromium/screenshot";
    /**
     * The path for PDF engine-related operations.
     * @type {string}
     */
    static readonly PDF_ENGINES_PATH = "forms/pdfengines";
    /**
     * The path for LibreOffice-related conversions.
     * @type {string}
     */
    static readonly LIBRE_OFFICE_PATH = "forms/libreoffice";
    /**
     * Routes for Chromium conversions.
     * @type {Object}
     */
    static readonly CHROMIUM_ROUTES: {
        url: ChromiumRoute;
        html: ChromiumRoute;
        markdown: ChromiumRoute;
    };
    /**
     * Routes for PDF engine operations.
     * @type {Object}
     */
    static readonly PDF_ENGINE_ROUTES: {
        merge: PdfEngineRoute;
        readMetadata: PdfEngineRoute;
        writeMetadata: PdfEngineRoute;
    };
    /**
     * Routes for LibreOffice conversions.
     * @type {Object}
     */
    static readonly LIBRE_OFFICE_ROUTES: {
        convert: LibreOfficeRoute;
    };
}
export {};
