"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PDFEngineUtils = void 0;
const tslib_1 = require("tslib");
const fs_1 = require("fs");
const path_1 = tslib_1.__importDefault(require("path"));
/**
 * Utility class for handling common tasks related to PDF engine operations.
 */
class PDFEngineUtils {
    /**
     * Adds PDF files to the FormData object.
     *
     * @param {PathLikeOrReadStream[]} files - An array of PDF files to be added to the FormData.
     * @param {FormData} data - The FormData object to which PDF files will be added.
     * @throws {Error} Throws an error if the file extension is not supported.
     */
    static addFiles(files, data) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            for (const [key, file] of files.entries()) {
                const filename = `file${key}.pdf`;
                if (Buffer.isBuffer(file)) {
                    data.append('files', file, filename);
                }
                else if (file instanceof fs_1.ReadStream) {
                    data.append('files', file, filename);
                }
                else {
                    yield fs_1.promises.access(file, fs_1.constants.R_OK);
                    const filename = path_1.default.basename(file.toString());
                    const extension = path_1.default.extname(filename);
                    if (extension === '.pdf') {
                        data.append(filename, (0, fs_1.createReadStream)(file));
                    }
                    else {
                        throw new Error(`${extension} is not supported`);
                    }
                }
            }
        });
    }
}
exports.PDFEngineUtils = PDFEngineUtils;
//# sourceMappingURL=engine.utils.js.map